package net.sergeych.kiloparsec

/**
 * The local interface to provide functions, register errors for Kiloparsec users. Use it
 * with [KiloClient], [KiloClientConnection], [KiloServerConnection], etc.
 *
 * Base class implementation does the following:
 *
 * - It registers common exceptions from [RemoteInterface] and kotlin/java `IllegalArgumentException` and
 *      `IllegalStateException`
 * - It provides [onConnected] handler
 *
 * See [KiloServer] for usage sample.
 */
open class KiloInterface<S> : LocalInterface<KiloScope<S>>() {

    internal var onConnectHandler: (KiloScope<S>.()->Unit) ? = null

    fun onConnected(f: KiloScope<S>.()->Unit) { onConnectHandler = f }

    init {
        registerError { RemoteInterface.UnknownCommand() }
        registerError { RemoteInterface.InternalError(it) }
        registerError { RemoteInterface.ClosedException(it) }
//        registerError { RemoteInterface.SecurityException(it) }
        registerError { RemoteInterface.InvalidDataException(it) }
        registerError { RemoteInterface.RemoteException(it) }
        registerError { IllegalStateException() }
        registerError { IllegalArgumentException(it) }
    }
}

