package net.sergeych.kiloparsec

import kotlinx.coroutines.sync.Mutex
import kotlinx.coroutines.sync.withLock

fun String.encodeToUByteArray() =
    encodeToByteArray().toUByteArray()

class SyncValue<T>(initialValue: T) {
    private val access = Mutex()

    var value = initialValue
    private set

    suspend fun mutate(f: suspend (T)->T): T = access.withLock { f(value).also { value = it } }

    @Suppress("unused")
    suspend fun getAndSet(newValue: T): T = mutate {
        val old = value
        value = newValue
        old
    }

}
